@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -15,9 +15,7 @@ AutoCorrectionListWidget::AutoCorrectionListWidget(QWidget *parent)
 {
 }
 
-AutoCorrectionListWidget::~AutoCorrectionListWidget()
-{
-}
+AutoCorrectionListWidget::~AutoCorrectionListWidget() = default;
 
 void AutoCorrectionListWidget::keyPressEvent(QKeyEvent *event)
 {
