@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -36,10 +36,7 @@ RichTextEditWithAutoCorrection::RichTextEditWithAutoCorrection(QWidget *parent)
 {
 }
 
-RichTextEditWithAutoCorrection::~RichTextEditWithAutoCorrection()
-{
-    delete d;
-}
+RichTextEditWithAutoCorrection::~RichTextEditWithAutoCorrection() = default;
 
 void RichTextEditWithAutoCorrection::setAutocorrection(PimCommon::AutoCorrection *autocorrect)
 {
