@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -28,9 +28,7 @@ GoogleTranslator::GoogleTranslator(QObject *parent)
     connect(mNetworkAccessManager, &QNetworkAccessManager::finished, this, &GoogleTranslator::slotTranslateFinished);
 }
 
-GoogleTranslator::~GoogleTranslator()
-{
-}
+GoogleTranslator::~GoogleTranslator() = default;
 
 void GoogleTranslator::setParentWidget(QWidget *parent)
 {
@@ -164,7 +162,7 @@ void GoogleTranslator::translate()
     const QNetworkRequest request(url);
 
     QNetworkReply *reply = mNetworkAccessManager->get(request);
-    connect(reply, QOverload<QNetworkReply::NetworkError>::of(&QNetworkReply::errorOccurred), this, &GoogleTranslator::slotError);
+    connect(reply, &QNetworkReply::errorOccurred, this, &GoogleTranslator::slotError);
 }
 
 void GoogleTranslator::slotError(QNetworkReply::NetworkError /*error*/)
@@ -179,8 +177,8 @@ void GoogleTranslator::slotTranslateFinished(QNetworkReply *reply)
     reply->deleteLater();
     //  jsonData contains arrays like this: ["foo",,"bar"]
     //  but this is not valid JSON for QJSON, it expects empty strings: ["foo","","bar"]
-    mJsonData.replace(QRegExp(QLatin1String(",{3,3}")), QStringLiteral(",\"\",\"\","));
-    mJsonData.replace(QRegExp(QLatin1String(",{2,2}")), QStringLiteral(",\"\","));
+    mJsonData.replace(QRegularExpression(QLatin1String(",{3,3}")), QStringLiteral(",\"\",\"\","));
+    mJsonData.replace(QRegularExpression(QLatin1String(",{2,2}")), QStringLiteral(",\"\","));
     // qCDebug(PIMCOMMON_LOG) << mJsonData;
 
     QJsonParseError parsingError;
